slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPMonitorCancel

Clears all monitors for a PEP object.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPMonitorCancel(PEP pep)

Logically Collective on pep

### Input Parameters

| pep | - eigensolver context obtained from PEPCreate()

### Options Database Key

| -pep_monitor_cancel | - Cancels all monitors that have been hardwired into a code by calls to PEPMonitorSet(), but does not cancel those set via the options database.

### See Also

PEPMonitorSet()

### Level

intermediate

### Location

src/pep/interface/pepmon.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages